#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=mentone5.19_base.ps
projection=-JM16.0c+
region=-R-104.7/-103.9/31.4/31.8
gmt psbasemap $region $projection -Bxa0.2f0.1 -Bya0.2f0.1 -BWeSn+t'Base Map mentone5.19' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    31.677  -104.409
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    31.728  -104.355
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    31.661  -104.288
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    31.666  -104.374
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    31.678  -104.424
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    31.678  -104.410
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    31.671  -104.387
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    31.705  -104.147
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    31.674  -104.428
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    31.668  -104.393
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    31.616  -104.269
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    31.673  -104.420
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    31.678  -104.391
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    31.670  -104.400
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    31.617  -104.242
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    31.600  -104.004
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    31.597  -104.001
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    31.671  -104.398
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    31.707  -104.022
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    31.721  -104.540
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    31.567  -104.028
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    31.659  -104.315
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    31.656  -104.312
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    31.681  -104.481
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    31.724  -104.581
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    31.669  -104.398
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    31.675  -104.404
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    31.675  -104.436
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    31.616  -103.975
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    31.680  -104.409
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    31.618  -103.976
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    31.613  -103.975
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    31.614  -103.976
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    31.724  -104.581
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    31.727  -104.620
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    31.666  -104.546
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    31.682  -104.449
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    31.674  -104.403
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    31.727  -104.575
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    31.734  -104.609
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    31.679  -104.445
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    31.616  -103.991
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    31.613  -103.987
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    31.610  -103.983
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    31.674  -104.428
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    31.630  -104.008
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    31.627  -104.014
END
gmt psxy -: -R $projection -Sl8p+t"48" -G0 -O -K << END >> $psfile
    31.636  -103.992
END
gmt psxy -: -R $projection -Sl8p+t"49" -G0 -O -K << END >> $psfile
    31.634  -104.003
END
gmt psxy -: -R $projection -Sl8p+t"50" -G0 -O -K << END >> $psfile
    31.722  -104.579
END
gmt psxy -: -R $projection -Sl8p+t"51" -G0 -O -K << END >> $psfile
    31.634  -103.991
END
gmt psxy -: -R $projection -Sl8p+t"52" -G0 -O -K << END >> $psfile
    31.623  -104.007
END
gmt psxy -: -R $projection -Sl8p+t"53" -G0 -O -K << END >> $psfile
    31.671  -104.251
END
gmt psxy -: -R $projection -Sl8p+t"54" -G0 -O -K << END >> $psfile
    31.674  -104.398
END
gmt psxy -: -R $projection -Sl8p+t"55" -G0 -O -K << END >> $psfile
    31.677  -104.402
END
gmt psxy -: -R $projection -Sl8p+t"56" -G0 -O -K << END >> $psfile
    31.615  -103.975
END
gmt psxy -: -R $projection -Sl8p+t"57" -G0 -O -K << END >> $psfile
    31.669  -104.387
END
gmt psxy -: -R $projection -Sl8p+t"58" -G0 -O -K << END >> $psfile
    31.662  -104.383
END
gmt psxy -: -R $projection -Sl8p+t"59" -G0 -O -K << END >> $psfile
    31.612  -103.991
END
gmt psxy -: -R $projection -Sl8p+t"60" -G0 -O -K << END >> $psfile
    31.659  -104.367
END
gmt psxy -: -R $projection -Sl8p+t"61" -G0 -O -K << END >> $psfile
    31.664  -104.374
END
gmt psxy -: -R $projection -Sl8p+t"62" -G0 -O -K << END >> $psfile
    31.684  -104.471
END
gmt psxy -: -R $projection -Sl8p+t"63" -G0 -O -K << END >> $psfile
    31.532  -104.169
END
gmt psxy -: -R $projection -Sl8p+t"64" -G0 -O -K << END >> $psfile
    31.531  -104.166
END
gmt psxy -: -R $projection -Sl8p+t"65" -G0 -O -K << END >> $psfile
    31.555  -104.106
END
gmt psxy -: -R $projection -Sl8p+t"66" -G0 -O -K << END >> $psfile
    31.665  -104.386
END
gmt psxy -: -R $projection -Sl8p+t"67" -G0 -O -K << END >> $psfile
    31.680  -104.474
END
gmt psxy -: -R $projection -Sl8p+t"68" -G0 -O -K << END >> $psfile
    31.663  -104.385
END
gmt psxy -: -R $projection -Sl8p+t"69" -G0 -O -K << END >> $psfile
    31.624  -103.986
END
gmt psxy -: -R $projection -Sl8p+t"70" -G0 -O -K << END >> $psfile
    31.666  -104.384
END
gmt psxy -: -R $projection -Sl8p+t"71" -G0 -O -K << END >> $psfile
    31.740  -104.117
END
gmt psxy -: -R $projection -Sl8p+t"72" -G0 -O -K << END >> $psfile
    31.614  -103.971
END
gmt psxy -: -R $projection -Sl8p+t"73" -G0 -O -K << END >> $psfile
    31.677  -104.433
END
gmt psxy -: -R $projection -Sl8p+t"74" -G0 -O -K << END >> $psfile
    31.610  -103.991
END
gmt psxy -: -R $projection -Sl8p+t"75" -G0 -O -K << END >> $psfile
    31.668  -104.205
END
gmt psxy -: -R $projection -Sl8p+t"76" -G0 -O -K << END >> $psfile
    31.671  -104.210
END
gmt psxy -: -R $projection -Sl8p+t"77" -G0 -O -K << END >> $psfile
    31.672  -104.208
END
gmt psxy -: -R $projection -Sl8p+t"78" -G0 -O -K << END >> $psfile
    31.672  -104.200
END
gmt psxy -: -R $projection -Sl8p+t"79" -G0 -O -K << END >> $psfile
    31.677  -104.209
END
gmt psxy -: -R $projection -Sl8p+t"80" -G0 -O -K << END >> $psfile
    31.679  -104.408
END
gmt psxy -: -R $projection -Sl8p+t"81" -G0 -O -K << END >> $psfile
    31.673  -104.425
END
gmt psxy -: -R $projection -Sl8p+t"82" -G0 -O -K << END >> $psfile
    31.635  -104.492
END
gmt psxy -: -R $projection -Sl8p+t"83" -G0 -O -K << END >> $psfile
    31.659  -104.377
END
gmt psxy -: -R $projection -Sl8p+t"84" -G0 -O -K << END >> $psfile
    31.658  -104.373
END
gmt psxy -: -R $projection -Sl8p+t"85" -G0 -O -K << END >> $psfile
    31.560  -104.103
END
gmt psxy -: -R $projection -Sl8p+t"86" -G0 -O -K << END >> $psfile
    31.555  -104.111
END
gmt psxy -: -R $projection -Sl8p+t"87" -G0 -O -K << END >> $psfile
    31.657  -104.376
END
gmt psxy -: -R $projection -Sl8p+t"88" -G0 -O -K << END >> $psfile
    31.678  -104.102
END
gmt psxy -: -R $projection -Sl8p+t"89" -G0 -O -K << END >> $psfile
    31.601  -104.545
END
gmt psxy -: -R $projection -Sl8p+t"90" -G0 -O -K << END >> $psfile
    31.656  -104.371
END
gmt psxy -: -R $projection -Sl8p+t"91" -G0 -O -K << END >> $psfile
    31.663  -104.213
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.676  -104.408
    31.677  -104.409
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.671  -104.395
    31.677  -104.409
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.728  -104.354
    31.728  -104.355
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.716  -104.340
    31.728  -104.355
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.661  -104.287
    31.661  -104.288
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.645  -104.267
    31.661  -104.288
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.666  -104.373
    31.666  -104.374
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.669  -104.339
    31.666  -104.374
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.678  -104.424
    31.678  -104.424
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.663  -104.406
    31.678  -104.424
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.678  -104.409
    31.678  -104.410
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.671  -104.392
    31.678  -104.410
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.670  -104.387
    31.671  -104.387
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.662  -104.380
    31.671  -104.387
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.705  -104.146
    31.705  -104.147
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.704  -104.144
    31.705  -104.147
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.674  -104.427
    31.674  -104.428
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.666  -104.411
    31.674  -104.428
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.668  -104.392
    31.668  -104.393
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.663  -104.377
    31.668  -104.393
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.616  -104.269
    31.616  -104.269
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.619  -104.200
    31.616  -104.269
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.673  -104.419
    31.673  -104.420
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.663  -104.408
    31.673  -104.420
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.678  -104.390
    31.678  -104.391
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.674  -104.380
    31.678  -104.391
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.671  -104.399
    31.670  -104.400
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.664  -104.385
    31.670  -104.400
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.618  -104.241
    31.617  -104.242
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.604  -104.228
    31.617  -104.242
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.600  -104.004
    31.600  -104.004
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.598  -103.990
    31.600  -104.004
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.598  -104.001
    31.597  -104.001
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.591  -103.994
    31.597  -104.001
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.671  -104.397
    31.671  -104.398
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.653  -104.378
    31.671  -104.398
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.708  -104.023
    31.707  -104.022
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.703  -104.018
    31.707  -104.022
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.721  -104.539
    31.721  -104.540
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.706  -104.528
    31.721  -104.540
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.567  -104.028
    31.567  -104.028
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.555  -104.018
    31.567  -104.028
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.659  -104.314
    31.659  -104.315
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.650  -104.309
    31.659  -104.315
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.656  -104.312
    31.656  -104.312
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.650  -104.300
    31.656  -104.312
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.681  -104.480
    31.681  -104.481
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.662  -104.475
    31.681  -104.481
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.724  -104.580
    31.724  -104.581
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.708  -104.544
    31.724  -104.581
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.669  -104.397
    31.669  -104.398
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.666  -104.387
    31.669  -104.398
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.675  -104.403
    31.675  -104.404
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.659  -104.385
    31.675  -104.404
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.675  -104.435
    31.675  -104.436
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.664  -104.416
    31.675  -104.436
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.616  -103.975
    31.616  -103.975
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.607  -103.974
    31.616  -103.975
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.680  -104.409
    31.680  -104.409
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.667  -104.392
    31.680  -104.409
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.619  -103.975
    31.618  -103.976
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.606  -103.960
    31.618  -103.976
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.613  -103.975
    31.613  -103.975
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.615  -103.964
    31.613  -103.975
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.614  -103.976
    31.614  -103.976
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.621  -103.956
    31.614  -103.976
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.724  -104.581
    31.724  -104.581
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.748  -104.559
    31.724  -104.581
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.725  -104.624
    31.727  -104.620
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.720  -104.583
    31.727  -104.620
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.666  -104.544
    31.666  -104.546
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.646  -104.517
    31.666  -104.546
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.682  -104.448
    31.682  -104.449
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.683  -104.425
    31.682  -104.449
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.674  -104.402
    31.674  -104.403
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.666  -104.385
    31.674  -104.403
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.726  -104.575
    31.727  -104.575
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.727  -104.572
    31.727  -104.575
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.735  -104.608
    31.734  -104.609
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.715  -104.584
    31.734  -104.609
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.678  -104.444
    31.679  -104.445
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.677  -104.409
    31.679  -104.445
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.617  -103.991
    31.616  -103.991
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.607  -103.987
    31.616  -103.991
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.613  -103.987
    31.613  -103.987
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.627  -103.953
    31.613  -103.987
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.611  -103.982
    31.610  -103.983
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.606  -103.975
    31.610  -103.983
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.674  -104.428
    31.674  -104.428
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.670  -104.402
    31.674  -104.428
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.630  -104.008
    31.630  -104.008
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.625  -103.999
    31.630  -104.008
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.628  -104.014
    31.627  -104.014
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.623  -103.997
    31.627  -104.014
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.636  -103.992
    31.636  -103.992
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.633  -103.991
    31.636  -103.992
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.634  -104.004
    31.634  -104.003
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.633  -104.002
    31.634  -104.003
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.722  -104.578
    31.722  -104.579
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.713  -104.554
    31.722  -104.579
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.634  -103.991
    31.634  -103.991
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.618  -103.981
    31.634  -103.991
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.623  -104.007
    31.623  -104.007
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.611  -103.985
    31.623  -104.007
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.671  -104.252
    31.671  -104.251
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.660  -104.248
    31.671  -104.251
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.674  -104.398
    31.674  -104.398
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.668  -104.395
    31.674  -104.398
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.678  -104.401
    31.677  -104.402
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.677  -104.398
    31.677  -104.402
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.616  -103.975
    31.615  -103.975
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.619  -103.975
    31.615  -103.975
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.669  -104.387
    31.669  -104.387
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.667  -104.373
    31.669  -104.387
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.662  -104.383
    31.662  -104.383
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.657  -104.366
    31.662  -104.383
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.612  -103.991
    31.612  -103.991
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.608  -103.985
    31.612  -103.991
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.659  -104.367
    31.659  -104.367
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.660  -104.360
    31.659  -104.367
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.664  -104.374
    31.664  -104.374
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.662  -104.353
    31.664  -104.374
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.684  -104.471
    31.684  -104.471
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.665  -104.441
    31.684  -104.471
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.532  -104.169
    31.532  -104.169
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.524  -104.142
    31.532  -104.169
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.531  -104.165
    31.531  -104.166
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.528  -104.158
    31.531  -104.166
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.556  -104.105
    31.555  -104.106
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.554  -104.096
    31.555  -104.106
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.664  -104.386
    31.665  -104.386
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.653  -104.365
    31.665  -104.386
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.680  -104.474
    31.680  -104.474
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.673  -104.457
    31.680  -104.474
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.662  -104.384
    31.663  -104.385
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.646  -104.364
    31.663  -104.385
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.624  -103.987
    31.624  -103.986
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.613  -103.942
    31.624  -103.986
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.665  -104.383
    31.666  -104.384
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.661  -104.376
    31.666  -104.384
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.740  -104.117
    31.740  -104.117
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.733  -104.113
    31.740  -104.117
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.614  -103.972
    31.614  -103.971
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.604  -103.942
    31.614  -103.971
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.677  -104.433
    31.677  -104.433
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.663  -104.414
    31.677  -104.433
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.610  -103.991
    31.610  -103.991
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.608  -103.985
    31.610  -103.991
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.668  -104.205
    31.668  -104.205
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.660  -104.198
    31.668  -104.205
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.671  -104.210
    31.671  -104.210
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.671  -104.199
    31.671  -104.210
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.673  -104.208
    31.672  -104.208
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.667  -104.208
    31.672  -104.208
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.672  -104.200
    31.672  -104.200
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.675  -104.196
    31.672  -104.200
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.677  -104.208
    31.677  -104.209
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.672  -104.201
    31.677  -104.209
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.679  -104.407
    31.679  -104.408
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.618  -104.406
    31.679  -104.408
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.672  -104.424
    31.673  -104.425
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.644  -104.371
    31.673  -104.425
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.635  -104.490
    31.635  -104.492
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.624  -104.466
    31.635  -104.492
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.659  -104.376
    31.659  -104.377
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.650  -104.358
    31.659  -104.377
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.658  -104.372
    31.658  -104.373
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.642  -104.350
    31.658  -104.373
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.561  -104.102
    31.560  -104.103
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.550  -104.094
    31.560  -104.103
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.555  -104.110
    31.555  -104.111
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.557  -104.100
    31.555  -104.111
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.657  -104.375
    31.657  -104.376
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.650  -104.358
    31.657  -104.376
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.677  -104.102
    31.678  -104.102
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.665  -104.093
    31.678  -104.102
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.601  -104.544
    31.601  -104.545
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.603  -104.545
    31.601  -104.545
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.656  -104.370
    31.656  -104.371
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.657  -104.358
    31.656  -104.371
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    31.662  -104.205
    31.663  -104.213
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    31.645  -104.205
    31.663  -104.213
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    31.677  -104.409   -45.136     0.630     0.885
    31.728  -104.355   -48.853     0.531     0.669
    31.661  -104.288   -44.346     0.501     0.684
    31.666  -104.374   -47.480     0.530     0.746
    31.678  -104.424   -45.759     0.661     0.818
    31.678  -104.410   -39.476     0.523     0.747
    31.671  -104.387   -41.329     0.579     0.784
    31.705  -104.147   -36.829     0.466     0.683
    31.674  -104.428   -33.517     0.600     0.816
    31.668  -104.393   -33.708     0.498     0.706
    31.616  -104.269   -46.498     0.496     0.672
    31.673  -104.420   -51.002     0.539     0.769
    31.678  -104.391   -45.324     0.668     0.878
    31.670  -104.400   -48.152     0.489     0.644
    31.617  -104.242   -39.653     0.383     0.591
    31.600  -104.004   -36.557     0.335     0.607
    31.597  -104.001   -35.669     0.380     0.665
    31.671  -104.398   -41.449     0.561     0.741
    31.707  -104.022   -31.679     0.505     0.729
    31.721  -104.540   -22.443     0.642     0.825
    31.567  -104.028   -37.667     0.372     0.662
    31.659  -104.315   -40.170     0.587     0.726
    31.656  -104.312   -40.456     0.494     0.658
    31.681  -104.481   -28.346     0.686     0.873
    31.724  -104.581     5.490     1.007     1.112
    31.669  -104.398   -59.960     0.601     0.699
    31.675  -104.404   -42.670     0.795     0.962
    31.675  -104.436   -24.534     0.652     0.789
    31.616  -103.975   -35.612     0.557     0.810
    31.680  -104.409   -61.984     0.623     0.760
    31.618  -103.976   -37.243     0.609     0.917
    31.613  -103.975   -39.318     0.386     0.713
    31.614  -103.976   -39.605     0.438     0.715
    31.724  -104.581    -7.894     0.736     0.845
    31.727  -104.620   -12.220     1.062     1.759
    31.666  -104.546   -17.538     0.889     1.131
    31.682  -104.449   -38.243     0.718     0.866
    31.674  -104.403   -31.527     0.629     0.749
    31.727  -104.575    31.068     1.104     1.286
    31.734  -104.609   -31.195     0.766     0.996
    31.679  -104.445   -43.536     0.485     0.570
    31.616  -103.991   -32.918     0.582     0.875
    31.613  -103.987   -32.488     0.562     0.736
    31.610  -103.983   -37.504     0.445     0.813
    31.674  -104.428   -39.740     0.573     0.846
    31.630  -104.008   -42.431     0.334     0.480
    31.627  -104.014   -33.614     0.413     0.546
    31.636  -103.992   -43.466     0.378     0.503
    31.634  -104.003   -35.522     0.354     0.474
    31.722  -104.579    -2.755     0.985     1.279
    31.634  -103.991   -32.833     0.425     0.496
    31.623  -104.007   -42.304     0.456     0.605
    31.671  -104.251   -72.428     0.548     0.774
    31.674  -104.398   -53.759     0.497     0.635
    31.677  -104.402   -60.504     0.499     0.703
    31.615  -103.975   -32.381     0.595     0.719
    31.669  -104.387   -67.622     0.481     0.679
    31.662  -104.383   -67.536     0.523     0.681
    31.612  -103.991   -47.499     0.348     0.496
    31.659  -104.367   -57.363     0.437     0.623
    31.664  -104.374   -52.563     0.455     0.629
    31.684  -104.471   -42.341     0.657     0.735
    31.532  -104.169   -32.485     0.487     0.734
    31.531  -104.166   -27.876     0.555     0.754
    31.555  -104.106   -14.869     0.718     0.870
    31.665  -104.386   -64.095     0.513     0.675
    31.680  -104.474   -57.362     0.521     0.701
    31.663  -104.385   -67.658     0.533     0.751
    31.624  -103.986   -13.060     0.681     0.698
    31.666  -104.384   -72.279     0.476     0.593
    31.740  -104.117   -46.145     0.496     0.557
    31.614  -103.971   -41.233     0.441     0.604
    31.677  -104.433   -36.642     0.421     0.521
    31.610  -103.991   -52.367     0.674     0.800
    31.668  -104.205   -60.925     0.582     0.738
    31.671  -104.210   -62.893     0.441     0.596
    31.672  -104.208   -74.037     0.607     0.744
    31.672  -104.200   -52.177     0.388     0.557
    31.677  -104.209   -47.311     0.463     0.610
    31.679  -104.408   -63.162     0.692     1.018
    31.673  -104.425   -49.100     0.656     0.779
    31.635  -104.492   -25.642     0.847     0.960
    31.659  -104.377   -37.416     0.675     0.905
    31.658  -104.373   -50.681     0.565     0.848
    31.560  -104.103   -17.431     0.634     0.779
    31.555  -104.111   -29.338     0.720     0.859
    31.657  -104.376   -28.907     0.467     0.701
    31.678  -104.102   -84.783     0.672     0.722
    31.601  -104.545   -31.886     0.574     0.795
    31.656  -104.371   -57.977     0.446     0.612
    31.663  -104.213    21.050     1.183     1.334
END

# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    31.485  -104.661   -62.379     0.497     0.613
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    31.485  -104.638   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    31.485  -104.661     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    31.485  -104.661     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    31.440  -104.661   5 km
END
